@@ -432,7 +432,7 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
 
     parser.add_argument("--chromecast-device", "--cast-to", "-t", default=default_chromecast, help=argparse.SUPPRESS)
     parser.add_argument("--chromecast", "--cast", "-c", action="store_true", help=argparse.SUPPRESS)
-    parser.add_argument("--with-local", "-wl", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--cast-with-local", "-wl", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--loop", action="store_true", help=argparse.SUPPRESS)
 
     parser.add_argument("--interdimensional-cable", "-4dtv", type=int, help=argparse.SUPPRESS)
@@ -462,7 +462,7 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--moved", nargs=2, help=argparse.SUPPRESS)
 
     parser.add_argument("--cols", "-cols", "-col", nargs="*", help=argparse.SUPPRESS)
-    parser.add_argument("--limit", "-L", "-l", "-queue", "--queue", help=argparse.SUPPRESS)
+    parser.add_argument("--limit", "-L", "-queue", "--queue", help=argparse.SUPPRESS)
     parser.add_argument("--skip", "-S", help=argparse.SUPPRESS)
     parser.add_argument(
         "--partial", "-P", "--recent", "-R", default=False, const="n", nargs="?", help=argparse.SUPPRESS
@@ -474,12 +474,8 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--watch-later-directory", default=consts.DEFAULT_MPV_WATCH_LATER, help=argparse.SUPPRESS)
 
     parser.add_argument("--override-player", "--player", "-player", help=argparse.SUPPRESS)
-    parser.add_argument(
-        "--player-args-sub", "-player-sub", nargs="*", default=DEFAULT_PLAYER_ARGS_SUB, help=argparse.SUPPRESS
-    )
-    parser.add_argument(
-        "--player-args-no-sub", "-player-no-sub", nargs="*", default=DEFAULT_PLAYER_ARGS_NO_SUB, help=argparse.SUPPRESS
-    )
+    parser.add_argument("--player-args-sub", "-player-sub", nargs="*", default=DEFAULT_PLAYER_ARGS_SUB)
+    parser.add_argument("--player-args-no-sub", "-player-no-sub", nargs="*", default=DEFAULT_PLAYER_ARGS_NO_SUB)
     parser.add_argument("--transcode", action="store_true", help=argparse.SUPPRESS)
 
     parser.add_argument("--post-action", "--action", "-k", default="keep", help=argparse.SUPPRESS)
@@ -487,8 +483,8 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--keep-cmd", "--keepcmd", help=argparse.SUPPRESS)
     parser.add_argument("--shallow-organize", default="/mnt/d/", help=argparse.SUPPRESS)
 
-    parser.add_argument("--online-media-only", "--online-only", action="store_true", help=argparse.SUPPRESS)
-    parser.add_argument("--local-media-only", "--local-only", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--online-media-only", "--online-only", "-o", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--local-media-only", "--local-only", "-l", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--safe", "-safe", action="store_true", help="Skip generic URLs")
 
     parser.add_argument("--timeout", "-T", help=argparse.SUPPRESS)
@@ -563,7 +559,7 @@ def chromecast_play(args, m) -> None:
 
     if catt_log:
         if catt_log.stderr is None or catt_log.stderr == "":
-            if not args.with_local:
+            if not args.cast_with_local:
                 raise Exception("catt does not exit nonzero? but something might have gone wrong")
         elif "Heartbeat timeout, resetting connection" in catt_log.stderr:
             raise Exception("Media is possibly partially unwatched")
@@ -596,7 +592,7 @@ def play(args, m: Dict) -> None:
     media_file = m["path"]
 
     if args.safe and not tube_backend.is_supported(m["path"]):
-        log.warning("[%s]: Unsupported URL (safe_mode)", m["path"])
+        log.info("[%s]: Skipping unsupported URL (safe_mode)", m["path"])
         return
 
     if is_play_in_order_lvl2(args, media_file):
