@@ -283,6 +283,7 @@ def post_act(args, media_file: str, action=None) -> None:
                 delete_media(args, media_file)
 
         elif action == "askkeep":
+            utils.clear_input()
             if not Confirm.ask("Keep?", default=False):
                 delete_media(args, media_file)
             else:
@@ -401,7 +402,7 @@ def watch_chromecast(args, m: dict, subtitles_file=None) -> Optional[subprocess.
 def listen_chromecast(args, m: dict) -> Optional[subprocess.CompletedProcess]:
     Path(consts.CAST_NOW_PLAYING).write_text(m["path"])
     Path(consts.FAKE_SUBTITLE).touch()
-    if args.with_local:
+    if args.cast_with_local:
         cast_process = subprocess.Popen(
             ["catt", "-d", args.chromecast_device, "cast", "-s", consts.FAKE_SUBTITLE, m["path"]],
             **utils.os_bg_kwargs(),
@@ -575,7 +576,7 @@ def multiple_player(args, media) -> None:
     template = get_multiple_player_template(args)
     players = []
 
-    media = reversed(media)  # because I use media.pop()
+    media.reverse()  # because I use media.pop()
     try:
         while media or players:
             for t_idx, t in enumerate(template):
